@@ -1,3 +1,4 @@
+import cgi
 import json
 import threading
 
@@ -6,7 +7,8 @@ from debug_toolbar.panels import Panel
 from debug_toolbar.utils import get_stack, render_stacktrace, ThreadCollector, tidy_stacktrace
 from django.utils.functional import cached_property
 from django.utils.translation import gettext_lazy as _, ngettext
-from requests import sessions
+import requests
+import requests.sessions
 
 
 collector = ThreadCollector()
@@ -42,8 +44,13 @@ class RequestInfo:
     @cached_property
     def request_body(self):
         if self.request.body:
-            if self.request.headers['content-type'] == 'application/json':
-                return self._format_json(self.request.body)
+            content_type = self.request.headers.get('content-type')
+            if content_type:
+                content_type, params = cgi.parse_header(content_type)
+                if content_type == 'application/json':
+                    return self._format_json(self.request.body)
+                if isinstance(self.request.body, bytes) and params.get('charset'):
+                    return self.request.body.decode(params['charset'])
         return self.request.body
 
     @cached_property
@@ -56,10 +63,12 @@ class RequestInfo:
         if self.response.content:
             if self.response.headers['content-type'] == 'application/json':
                 return self._format_json(self.response.content)
+            if isinstance(self.response.content, bytes):
+                return self.response.content.decode(self.response.encoding)
         return self.response.content
 
 
-class PatchedSession(sessions.Session):
+class PatchedSession(requests.sessions.Session):
     """
     A patched requests `Session` class that collects all requests and responses.
     """
@@ -70,7 +79,8 @@ class PatchedSession(sessions.Session):
         return response
 
 
-sessions.Session = PatchedSession
+requests.Session = PatchedSession
+requests.sessions.Session = PatchedSession
 
 
 class RequestsDebugPanel(Panel):
